==> ZenTaoPMS.17.4.php5.4_5.6.zip: zentaopms/extension/max/assetlib/lang/zh-tw.php <==
<?php
$lang->assetlib->storyLib       = '需求庫';
$lang->assetlib->caseLib        = '用例庫';
$lang->assetlib->issueLib       = '問題庫';
$lang->assetlib->riskLib        = '風險庫';
$lang->assetlib->opportunityLib = '機會庫';
$lang->assetlib->practiceLib    = '最佳實踐庫';
$lang->assetlib->componentLib   = '組件庫';
$lang->assetlib->browse         = '瀏覽列表';
$lang->assetlib->all            = '所有';
$lang->assetlib->story          = '需求列表';
$lang->assetlib->issue          = '問題列表';
$lang->assetlib->risk           = '風險列表';
$lang->assetlib->opportunity    = '機會列表';
$lang->assetlib->practice       = '實踐列表';
$lang->assetlib->component      = '組件列表';
$lang->assetlib->libView        = '查看庫概況';
$lang->assetlib->deleted        = '已刪除';

$lang->assetlib->allStoryLib       = '所有需求庫';
$lang->assetlib->allCaseLib        = '所有用例庫';
$lang->assetlib->allIssueLib       = '所有問題庫';
$lang->assetlib->allRiskLib        = '所有風險庫';
$lang->assetlib->allOpportunityLib = '所有機會庫';
$lang->assetlib->allPracticeLib    = '所有最佳實踐庫';
$lang->assetlib->allComponentLib   = '所有組件庫';

/* Fields */
$lang->assetlib->id                = 'ID';
$lang->assetlib->name              = '名稱';
$lang->assetlib->desc              = '描述';
$lang->assetlib->pri               = '優先順序';
$lang->assetlib->priAB             = 'P';
$lang->assetlib->status            = '狀態';
$lang->assetlib->estimate          = '預計';
$lang->assetlib->createdBy         = '創建人';
$lang->assetlib->createdDate       = '創建日期';
$lang->assetlib->approved          = '審批';
$lang->assetlib->approvedDate      = '審批日期';
$lang->assetlib->assignedTo        = '指派給';
$lang->assetlib->noAssigned        = '未指派';
$lang->assetlib->assignedDate      = '指派日期';
$lang->assetlib->approvedDate      = '審批日期';
$lang->assetlib->approveResult     = '審批結果';
$lang->assetlib->project           = '所屬項目';
$lang->assetlib->plan              = '所屬計劃';
$lang->assetlib->allProject        = '全部項目';
$lang->assetlib->importedBy        = '由誰導入';
$lang->assetlib->importedDate      = '導入日期';
$lang->assetlib->approvedBy        = '由誰審批';
$lang->assetlib->sourceStory       = '來源需求';
$lang->assetlib->sourceIssue       = '來源問題';
$lang->assetlib->sourceRisk        = '來源風險';
$lang->assetlib->sourceOpportunity = '來源機會';
$lang->assetlib->sourceDoc         = '來源文檔';
$lang->assetlib->lastEditedDate    = '最後修改日期';

/* Actions */
$lang->assetlib->createStoryLib           = '創建需求庫';
$lang->assetlib->createIssueLib           = '創建問題庫';
$lang->assetlib->createRiskLib            = '創建風險庫';
$lang->assetlib->createOpportunityLib     = '創建機會庫';
$lang->assetlib->createPracticeLib        = '創建最佳實踐庫';
$lang->assetlib->createComponentLib       = '創建組件庫';
$lang->assetlib->edit                     = '編輯';
$lang->assetlib->editStoryLib             = '編輯需求庫';
$lang->assetlib->editIssueLib             = '編輯問題庫';
$lang->assetlib->editRiskLib              = '編輯風險庫';
$lang->assetlib->editOpportunityLib       = '編輯機會庫';
$lang->assetlib->editPracticeLib          = '編輯最佳實踐庫';
$lang->assetlib->editComponentLib         = '編輯組件庫';
$lang->assetlib->deleteStoryLib           = '刪除需求庫';
$lang->assetlib->deleteIssueLib           = '刪除問題庫';
$lang->assetlib->deleteRiskLib            = '刪除風險庫';
$lang->assetlib->deleteOpportunityLib     = '刪除機會庫';
$lang->assetlib->deletePracticeLib        = '刪除最佳實踐庫';
$lang->assetlib->deleteComponentLib       = '刪除組件庫';
$lang->assetlib->assignToStory            = '指派需求';
$lang->assetlib->assignToIssue            = '指派問題';
$lang->assetlib->assignToRisk             = '指派風險';
$lang->assetlib->assignToOpportunity      = '指派機會';
$lang->assetlib->assignToPractice         = '指派實踐';
$lang->assetlib->assignToComponent        = '指派組件';
$lang->assetlib->batchAssignToStory       = '批量指派需求';
$lang->assetlib->batchAssignToIssue       = '批量指派問題';
$lang->assetlib->batchAssignToRisk        = '批量指派風險';
$lang->assetlib->batchAssignToOpportunity = '批量指派機會';
$lang->assetlib->batchAssignToPractice    = '批量指派實踐';
$lang->assetlib->batchAssignToComponent   = '批量指派組件';
$lang->assetlib->approve                  = '審批';
$lang->assetlib->approveStory             = '審批需求';
$lang->assetlib->approveIssue             = '審批問題';
$lang->assetlib->approveRisk              = '審批風險';
$lang->assetlib->approveOpportunity       = '審批機會';
$lang->assetlib->approvePractice          = '審批實踐';
$lang->assetlib->approveComponent         = '審批組件';
$lang->assetlib->batchApproveStory        = '批量審批需求';
$lang->assetlib->batchApproveIssue        = '批量審批問題';
$lang->assetlib->batchApproveRisk         = '批量審批風險';
$lang->assetlib->batchApproveOpportunity  = '批量審批機會';
$lang->assetlib->batchApprovePractice     = '批量審批實踐';
$lang->assetlib->batchApproveComponent    = '批量審批組件';
$lang->assetlib->editStory                = '編輯需求';
$lang->assetlib->editIssue                = '編輯問題';
$lang->assetlib->editRisk                 = '編輯風險';
$lang->assetlib->editOpportunity          = '編輯機會';
$lang->assetlib->editPractice             = '編輯實踐';
$lang->assetlib->editComponent            = '編輯組件';
$lang->assetlib->removeStory              = '移除需求';
$lang->assetlib->removeIssue              = '移除問題';
$lang->assetlib->removeRisk               = '移除風險';
$lang->assetlib->removeOpportunity        = '移除機會';
$lang->assetlib->removePractice           = '移除實踐';
$lang->assetlib->removeComponent          = '移除組件';
$lang->assetlib->batchRemoveStory         = '批量移除需求';
$lang->assetlib->batchRemoveIssue         = '批量移除問題';
$lang->assetlib->batchRemoveRisk          = '批量移除風險';
$lang->assetlib->batchRemoveOpportunity   = '批量移除機會';
$lang->assetlib->batchRemovePractice      = '批量移除實踐';
$lang->assetlib->batchRemoveComponent     = '批量移除組件';
$lang->assetlib->remove                   = '移除';

$lang->assetlib->view               = '查看庫詳情';
$lang->assetlib->storyLibView       = '需求庫詳情';
$lang->assetlib->issueLibView       = '問題庫詳情';
$lang->assetlib->riskLibView        = '風險庫詳情';
$lang->assetlib->opportunityLibView = '機會庫詳情';
$lang->assetlib->practiceLibView    = '最佳實踐庫詳情';
$lang->assetlib->componentLibView   = '組件庫詳情';
$lang->assetlib->storyView          = '需求詳情';
$lang->assetlib->issueView          = '問題詳情';
$lang->assetlib->riskView           = '風險詳情';
$lang->assetlib->opportunityView    = '機會詳情';
$lang->assetlib->practiceView       = '最佳實踐詳情';
$lang->assetlib->componentView      = '組件詳情';

$lang->assetlib->import            = '導入';
$lang->assetlib->importFromProject = '從項目中導入';
$lang->assetlib->importStory       = '導入需求';
$lang->assetlib->importIssue       = '導入問題';
$lang->assetlib->importRisk        = '導入風險';
$lang->assetlib->importOpportunity = '導入機會';
$lang->assetlib->importPractice    = '導入最佳實踐文檔';
$lang->assetlib->importComponent   = '導入組件文檔';

$lang->assetlib->selectProject = '請選擇項目';
$lang->assetlib->selectProduct = '請選擇產品';
$lang->assetlib->selectDocLib  = '請選擇文檔庫';
$lang->assetlib->noProject     = '現在還沒有項目，請先創建！';

$lang->assetlib->storyLibDelete       = '您確認要刪除該需求庫嗎？';
$lang->assetlib->issueLibDelete       = '您確認要刪除該問題庫嗎？';
$lang->assetlib->riskLibDelete        = '您確認要刪除該風險庫嗎？';
$lang->assetlib->opportunityLibDelete = '您確認要刪除該機會庫嗎？';
$lang->assetlib->practiceLibDelete    = '您確認要刪除該最佳實踐庫嗎？';
$lang->assetlib->componentLibDelete   = '您確認要刪除該組件庫嗎？';

$lang->assetlib->confirmDeleteStory       = '您確認要移除該需求嗎？';
$lang->assetlib->confirmDeleteIssue       = '您確認要移除該問題嗎？';
$lang->assetlib->confirmDeleteRisk        = '您確認要移除該風險嗎？';
$lang->assetlib->confirmDeleteOpportunity = '您確認要移除該機會嗎？';
$lang->assetlib->confirmDeletePractice    = '您確認要移除該最佳實踐文檔嗎？';
$lang->assetlib->confirmDeleteComponent   = '您確認要移除該組件文檔嗎？';

$lang->assetlib->lib       = '所屬庫';
$lang->assetlib->selectLib = '請選擇庫';
$lang->assetlib->noLibrary = '現在還沒有公共庫，請先創建！';

$lang->assetlib->featureBar['all']   = '所有';
$lang->assetlib->featureBar['draft'] = '待審批';

$lang->assetlib->statusList['active'] = '已入庫';
$lang->assetlib->statusList['draft']  = '待審批';

$lang->assetlib->resultList['pass']   = '通過';
$lang->assetlib->resultList['reject'] = '拒絶';

$lang->assetlib->byQuery = '搜索';

==> ZenTaoPMS.17.5.php5.4_5.6.zip: zentaopms/extension/max/assetlib/lang/zh-tw.php <==
<?php
$lang->assetlib->storyLib       = '需求庫';
$lang->assetlib->caseLib        = '用例庫';
$lang->assetlib->issueLib       = '問題庫';
$lang->assetlib->riskLib        = '風險庫';
$lang->assetlib->opportunityLib = '機會庫';
$lang->assetlib->practiceLib    = '最佳實踐庫';
$lang->assetlib->componentLib   = '組件庫';
$lang->assetlib->browse         = '瀏覽列表';
$lang->assetlib->all            = '所有';
$lang->assetlib->story          = '需求列表';
$lang->assetlib->issue          = '問題列表';
$lang->assetlib->risk           = '風險列表';
$lang->assetlib->opportunity    = '機會列表';
$lang->assetlib->practice       = '實踐列表';
$lang->assetlib->component      = '組件列表';
$lang->assetlib->libView        = '查看庫概況';
$lang->assetlib->deleted        = '已刪除';

$lang->assetlib->allStoryLib       = '所有需求庫';
$lang->assetlib->allCaseLib        = '所有用例庫';
$lang->assetlib->allIssueLib       = '所有問題庫';
$lang->assetlib->allRiskLib        = '所有風險庫';
$lang->assetlib->allOpportunityLib = '所有機會庫';
$lang->assetlib->allPracticeLib    = '所有最佳實踐庫';
$lang->assetlib->allComponentLib   = '所有組件庫';

/* Fields */
$lang->assetlib->id                = 'ID';
$lang->assetlib->name              = '名稱';
$lang->assetlib->desc              = '描述';
$lang->assetlib->pri               = '優先順序';
$lang->assetlib->priAB             = 'P';
$lang->assetlib->status            = '狀態';
$lang->assetlib->estimate          = '預計';
$lang->assetlib->createdBy         = '創建人';
$lang->assetlib->createdDate       = '創建日期';
$lang->assetlib->approved          = '審批';
$lang->assetlib->approvedDate      = '審批日期';
$lang->assetlib->assignedTo        = '指派給';
$lang->assetlib->noAssigned        = '未指派';
$lang->assetlib->assignedDate      = '指派日期';
$lang->assetlib->approvedDate      = '審批日期';
$lang->assetlib->approveResult     = '審批結果';
$lang->assetlib->project           = '所屬項目';
$lang->assetlib->plan              = '所屬計劃';
$lang->assetlib->allProject        = '全部項目';
$lang->assetlib->importedBy        = '由誰導入';
$lang->assetlib->importedDate      = '導入日期';
$lang->assetlib->approvedBy        = '由誰審批';
$lang->assetlib->sourceStory       = '來源需求';
$lang->assetlib->sourceIssue       = '來源問題';
$lang->assetlib->sourceRisk        = '來源風險';
$lang->assetlib->sourceOpportunity = '來源機會';
$lang->assetlib->sourceDoc         = '來源文檔';
$lang->assetlib->lastEditedDate    = '最後修改日期';

/* Actions */
$lang->assetlib->createStoryLib           = '創建需求庫';
$lang->assetlib->createIssueLib           = '創建問題庫';
$lang->assetlib->createRiskLib            = '創建風險庫';
$lang->assetlib->createOpportunityLib     = '創建機會庫';
$lang->assetlib->createPracticeLib        = '創建最佳實踐庫';
$lang->assetlib->createComponentLib       = '創建組件庫';
$lang->assetlib->edit                     = '編輯';
$lang->assetlib->editStoryLib             = '編輯需求庫';
$lang->assetlib->editIssueLib             = '編輯問題庫';
$lang->assetlib->editRiskLib              = '編輯風險庫';
$lang->assetlib->editOpportunityLib       = '編輯機會庫';
$lang->assetlib->editPracticeLib          = '編輯最佳實踐庫';
$lang->assetlib->editComponentLib         = '編輯組件庫';
$lang->assetlib->deleteStoryLib           = '刪除需求庫';
$lang->assetlib->deleteIssueLib           = '刪除問題庫';
$lang->assetlib->deleteRiskLib            = '刪除風險庫';
$lang->assetlib->deleteOpportunityLib     = '刪除機會庫';
$lang->assetlib->deletePracticeLib        = '刪除最佳實踐庫';
$lang->assetlib->deleteComponentLib       = '刪除組件庫';
$lang->assetlib->assignToStory            = '指派需求';
$lang->assetlib->assignToIssue            = '指派問題';
$lang->assetlib->assignToRisk             = '指派風險';
$lang->assetlib->assignToOpportunity      = '指派機會';
$lang->assetlib->assignToPractice         = '指派實踐';
$lang->assetlib->assignToComponent        = '指派組件';
$lang->assetlib->batchAssignToStory       = '批量指派需求';
$lang->assetlib->batchAssignToIssue       = '批量指派問題';
$lang->assetlib->batchAssignToRisk        = '批量指派風險';
$lang->assetlib->batchAssignToOpportunity = '批量指派機會';
$lang->assetlib->batchAssignToPractice    = '批量指派實踐';
$lang->assetlib->batchAssignToComponent   = '批量指派組件';
$lang->assetlib->approve                  = '審批';
$lang->assetlib->approveStory             = '審批需求';
$lang->assetlib->approveIssue             = '審批問題';
$lang->assetlib->approveRisk              = '審批風險';
$lang->assetlib->approveOpportunity       = '審批機會';
$lang->assetlib->approvePractice          = '審批實踐';
$lang->assetlib->approveComponent         = '審批組件';
$lang->assetlib->batchApproveStory        = '批量審批需求';
$lang->assetlib->batchApproveIssue        = '批量審批問題';
$lang->assetlib->batchApproveRisk         = '批量審批風險';
$lang->assetlib->batchApproveOpportunity  = '批量審批機會';
$lang->assetlib->batchApprovePractice     = '批量審批實踐';
$lang->assetlib->batchApproveComponent    = '批量審批組件';
$lang->assetlib->editStory                = '編輯需求';
$lang->assetlib->editIssue                = '編輯問題';
$lang->assetlib->editRisk                 = '編輯風險';
$lang->assetlib->editOpportunity          = '編輯機會';
$lang->assetlib->editPractice             = '編輯實踐';
$lang->assetlib->editComponent            = '編輯組件';
$lang->assetlib->removeStory              = '移除需求';
$lang->assetlib->removeIssue              = '移除問題';
$lang->assetlib->removeRisk               = '移除風險';
$lang->assetlib->removeOpportunity        = '移除機會';
$lang->assetlib->removePractice           = '移除實踐';
$lang->assetlib->removeComponent          = '移除組件';
$lang->assetlib->batchRemoveStory         = '批量移除需求';
$lang->assetlib->batchRemoveIssue         = '批量移除問題';
$lang->assetlib->batchRemoveRisk          = '批量移除風險';
$lang->assetlib->batchRemoveOpportunity   = '批量移除機會';
$lang->assetlib->batchRemovePractice      = '批量移除實踐';
$lang->assetlib->batchRemoveComponent     = '批量移除組件';
$lang->assetlib->remove                   = '移除';

$lang->assetlib->view               = '查看庫詳情';
$lang->assetlib->storyLibView       = '需求庫詳情';
$lang->assetlib->issueLibView       = '問題庫詳情';
$lang->assetlib->riskLibView        = '風險庫詳情';
$lang->assetlib->opportunityLibView = '機會庫詳情';
$lang->assetlib->practiceLibView    = '最佳實踐庫詳情';
$lang->assetlib->componentLibView   = '組件庫詳情';
$lang->assetlib->storyView          = '需求詳情';
$lang->assetlib->issueView          = '問題詳情';
$lang->assetlib->riskView           = '風險詳情';
$lang->assetlib->opportunityView    = '機會詳情';
$lang->assetlib->practiceView       = '最佳實踐詳情';
$lang->assetlib->componentView      = '組件詳情';

$lang->assetlib->import            = '導入';
$lang->assetlib->importFromProject = '從項目中導入';
$lang->assetlib->importStory       = '導入需求';
$lang->assetlib->importIssue       = '導入問題';
$lang->assetlib->importRisk        = '導入風險';
$lang->assetlib->importOpportunity = '導入機會';
$lang->assetlib->importPractice    = '導入最佳實踐文檔';
$lang->assetlib->importComponent   = '導入組件文檔';

$lang->assetlib->selectProject = '請選擇項目';
$lang->assetlib->selectProduct = '請選擇產品';
$lang->assetlib->selectDocLib  = '請選擇文檔庫';
$lang->assetlib->noProject     = '現在還沒有項目，請先創建！';

$lang->assetlib->storyLibDelete       = '您確認要刪除該需求庫嗎？';
$lang->assetlib->issueLibDelete       = '您確認要刪除該問題庫嗎？';
$lang->assetlib->riskLibDelete        = '您確認要刪除該風險庫嗎？';
$lang->assetlib->opportunityLibDelete = '您確認要刪除該機會庫嗎？';
$lang->assetlib->practiceLibDelete    = '您確認要刪除該最佳實踐庫嗎？';
$lang->assetlib->componentLibDelete   = '您確認要刪除該組件庫嗎？';

$lang->assetlib->confirmDeleteStory       = '您確認要移除該需求嗎？';
$lang->assetlib->confirmDeleteIssue       = '您確認要移除該問題嗎？';
$lang->assetlib->confirmDeleteRisk        = '您確認要移除該風險嗎？';
$lang->assetlib->confirmDeleteOpportunity = '您確認要移除該機會嗎？';
$lang->assetlib->confirmDeletePractice    = '您確認要移除該最佳實踐文檔嗎？';
$lang->assetlib->confirmDeleteComponent   = '您確認要移除該組件文檔嗎？';

$lang->assetlib->lib       = '所屬庫';
$lang->assetlib->selectLib = '請選擇庫';
$lang->assetlib->noLibrary = '現在還沒有公共庫，請先創建！';

$lang->assetlib->featureBar['browse']['all']   = '所有';
$lang->assetlib->featureBar['browse']['draft'] = '待審批';

$lang->assetlib->featureBar['caselib']['all'] = $lang->assetlib->all;

$lang->assetlib->statusList['active'] = '已入庫';
$lang->assetlib->statusList['draft']  = '待審批';

$lang->assetlib->resultList['pass']   = '通過';
$lang->assetlib->resultList['reject'] = '拒絶';

$lang->assetlib->byQuery = '搜索';
